==> streamlit_extras-0.0.2.tar.gz: streamlit_extras-0.0.2/README.md <==

<h1 align="center">
    🪢 streamlit-extras
</h1>

<p align="center">
    <strong>Discover, try, install and share Streamlit Extras!</strong>
</p>


<p align="center">
    <a href="https://extras.streamlitapp.com" title="Python Version"><img src="https://static.streamlit.io/badges/streamlit_badge_black_white.svg"></a><br>
    <a href="https://github.com/arnaudmiribel/streamlit-extras/" title="Python Version"><img src="https://img.shields.io/badge/Python-3.9%2B-blue&style=flat"></a>
</p>

<p align="center">
  <a href="#getting-started">Getting Started</a> •
  <a href="#documentation">Documentation</a> •
  <a href="https://github.com/arnaudmiribel/streamlit-extras/issues/new?labels=bug&template=01_bug-report.md">Report a Bug</a> •
  <a href="#contribution">Contribution</a>
</p>

`streamlit-extras` is a place for you to discover, try, install and share Streamlit re-usable bits we call <b><i>extras</i></b> Head over to <a href="extras.streamlitapp.com">extras.streamlitapp.com</a> to discover them and if you're seduced... go ahead and <a href="#getting-started">get started</a>!

<sup>Beta Version: Only suggested for experimental usage.</sup>


---

<p align="center">
     Try out and explore various examples in our playgrounds at <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a>.<br><br>
     <img src="https://user-images.githubusercontent.com/7164864/186383332-147e820d-cd02-4962-b8b9-91fe9f675dfe.gif" width="500px"></img>
</p>



---

## Highlights

- 📙&nbsp; <b>Discover:</b> Visit <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a> to discover all extras in their natural habitat
- 🛝&nbsp; <b>Try:</b> Our gallery gives a Streamlit-based playground for some extras. Try it before you <strike>buy</strike> install it!
- ⬇️&nbsp; <b>Install:</b> `streamlit-extras` is a PyPI package with all extras included. Catch them all using pip!
- 🫴&nbsp; <b>Share:</b> Go ahead and share your own extras, it's just a PR away!

## Getting Started

### Installation

```
pip install streamlit-extras
```

### Usage

Here's an example with one of the easiest extras around, <a href="https://extras.streamlitapp.com/Toggle%20button">stoggle</a>
```python
from streamlit_extras.stoggle import stoggle

stoggle("Summary", "More content that's hidden by default!")
```

## Documentation

Visit <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a>

## Contribution

PRs are welcome! Guidelines here at <a href="https://extras.streamlitapp.com/Contribute">extras.streamlitapp.com/Contribute</a>

<sup>README template taken from <a href="https://github.com/LukasMasuch/streamlit-pydantic">LukasMasuch/streamlit-pydantic</a></sup>

==> streamlit_extras-0.0.3.tar.gz: streamlit_extras-0.0.3/README.md <==

<h1 align="center">
    🪢 streamlit-extras
</h1>

<p align="center">
    <strong>Discover, try, install and share Streamlit Extras!</strong>
</p>


<p align="center">
    <a href="https://extras.streamlitapp.com" title="Python Version"><img src="https://static.streamlit.io/badges/streamlit_badge_black_white.svg"></a><br>
    <a href="https://github.com/arnaudmiribel/streamlit-extras/" title="Python Version"><img src="https://img.shields.io/badge/Python-3.9%2B-blue&style=flat"></a>
    <a href="https://badge.fury.io/py/streamlit-extras"><img src="https://badge.fury.io/py/streamlit-extras.svg" alt="PyPI version" height="18"></a>
    <a href="https://hits.seeyoufarm.com"><img src="https://hits.seeyoufarm.com/api/count/incr/badge.svg?url=https%3A%2F%2Fgithub.com%2Farnaudmiribel%2Fstreamlit-extras&count_bg=%2379C83D&title_bg=%23555555&icon=&icon_color=%23E7E7E7&title=visits&edge_flat=false"/></a>
</p>

<p align="center">
  <a href="#getting-started">Getting Started</a> •
  <a href="#documentation">Documentation</a> •
  <a href="https://github.com/arnaudmiribel/streamlit-extras/issues/new?labels=bug&template=01_bug-report.md">Report a Bug</a> •
  <a href="#contribution">Contribution</a>
</p>

`streamlit-extras` is a place for you to discover, try, install and share Streamlit re-usable bits we call <b><i>extras</i></b>. Head over to <a href="extras.streamlitapp.com">https://extras.streamlitapp.com</a> to discover them and if you're seduced... <a href="#getting-started">get started</a>!

<sup>Beta Version: Only suggested for experimental usage.</sup>


---

<p align="center">
     Try out and explore various examples in our playgrounds at <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a>.<br><br>
     <img src="https://user-images.githubusercontent.com/7164864/186383332-147e820d-cd02-4962-b8b9-91fe9f675dfe.gif" width="500px"></img>
</p>



---

## Highlights

- 📙&nbsp; <b>Discover:</b> Visit <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a> to discover all extras in their natural habitat
- 🛝&nbsp; <b>Try:</b> Our gallery gives a Streamlit-based playground for some extras. Try it before you <strike>buy</strike> install it!
- ⬇️&nbsp; <b>Install:</b> `streamlit-extras` is a PyPI package with all extras included. Catch them all using pip!
- 🫴&nbsp; <b>Share:</b> Go ahead and share your own extras, it's just a PR away!

## Getting Started

### Installation

```
pip install streamlit-extras
```

### Usage

Here's an example with one of the easiest extras around, <a href="https://extras.streamlitapp.com/Toggle%20button">stoggle</a>
```python
from streamlit_extras.stoggle import stoggle

stoggle("Summary", "More content that's hidden by default!")
```

## Documentation

Visit <a href="https://extras.streamlitapp.com">extras.streamlitapp.com</a>

## Contribution

PRs are welcome! Guidelines here at <a href="https://extras.streamlitapp.com/Contribute">extras.streamlitapp.com/Contribute</a>

<sup>README template taken from <a href="https://github.com/LukasMasuch/streamlit-pydantic">LukasMasuch/streamlit-pydantic</a></sup>
